@@ -34,8 +34,12 @@ struct IODelayReport {
 
 class IReporter {
 public:
+    IReporter() = default;
     virtual ~IReporter() = default;
 
+    IReporter(const IReporter&) = delete;
+    IReporter& operator=(const IReporter&) = delete;
+
     virtual void report(const LatencyReport& rep) = 0;
     virtual void report(const LossReport& rep) = 0;
     virtual void report(const IOJitterReport& rep) = 0;
