@@ -4,6 +4,7 @@
 #pragma once
 
 #include "core/Config.hpp"
+#include "core/DevInfo.hpp"
 #include "reports/IReporter.hpp"
 #include "reports/JsonPrinter.hpp"
 
@@ -11,21 +12,18 @@
 
 namespace signal_estimator {
 
-class JsonReporter : public IReporter {
+class JsonReporter final : public IReporter {
 public:
     JsonReporter(const Config& config, const DevInfo& dev_info, JsonPrinter& printer);
 
-    JsonReporter(const JsonReporter&) = delete;
-    JsonReporter& operator=(const JsonReporter&) = delete;
-
     void report(const LatencyReport& rep) override;
     void report(const LossReport& rep) override;
     void report(const IOJitterReport& rep) override;
     void report(const IODelayReport& rep) override;
 
 private:
-    JsonPrinter& printer_;
     const std::string dev_name_;
+    JsonPrinter& printer_;
 };
 
 } // namespace signal_estimator
