@@ -4,18 +4,17 @@
 #pragma once
 
 #include "core/Config.hpp"
+#include "core/DevInfo.hpp"
 #include "reports/IReporter.hpp"
+#include "reports/TextPrinter.hpp"
 
 #include <string>
 
 namespace signal_estimator {
 
-class TextReporter : public IReporter {
+class TextReporter final : public IReporter {
 public:
-    TextReporter(const Config& config, const DevInfo& dev_info);
-
-    TextReporter(const TextReporter&) = delete;
-    TextReporter& operator=(const TextReporter&) = delete;
+    TextReporter(const Config& config, const DevInfo& dev_info, TextPrinter& printer);
 
     void report(const LatencyReport& rep) override;
     void report(const LossReport& rep) override;
@@ -26,6 +25,7 @@ private:
     Config config_;
     bool sign_ {};
     std::string suffix_;
+    TextPrinter& printer_;
 };
 
 } // namespace signal_estimator
